@@ -1,27 +1,28 @@
 package Dist::Zilla::PluginBundle::BioPerl;
-BEGIN {
-  $Dist::Zilla::PluginBundle::BioPerl::AUTHORITY = 'cpan:BIOPERLML';
-}
-$Dist::Zilla::PluginBundle::BioPerl::VERSION = '0.23';
+$Dist::Zilla::PluginBundle::BioPerl::VERSION = '0.24';
 use utf8;
 
 # ABSTRACT: Build your distributions like Bioperl does
 # AUTHOR:   Florian Ragwitz <rafl@debian.org>
 # AUTHOR:   Sheena Scroggins
-# AUTHOR:   Carnë Draug <carandraug+dev@gmail.com
-# AUTHOR:   Chris Fields <cjfields1@gmail.com
+# AUTHOR:   Carnë Draug <carandraug+dev@gmail.com>
+# AUTHOR:   Chris Fields <cjfields1@gmail.com>
 # OWNER:    2010 Florian Ragwitz
 # OWNER:    2011 Sheena Scroggins
-# OWNER:    2013 Carnë Draug
+# OWNER:    2013-2017 Carnë Draug
 # LICENSE:  Perl_5
 
 use Moose 1.00;
 use MooseX::AttributeShortcuts;
-use MooseX::Types::URI qw(Uri);
 use MooseX::Types::Email qw(EmailAddress);
 use MooseX::Types::Moose qw(ArrayRef Bool Str);
 use namespace::autoclean;
-with qw/Dist::Zilla::Role::PluginBundle::Easy Dist::Zilla::Role::PluginBundle::PluginRemover Dist::Zilla::Role::PluginBundle::Config::Slicer/;
+
+with qw(
+  Dist::Zilla::Role::PluginBundle::Easy
+  Dist::Zilla::Role::PluginBundle::PluginRemover
+  Dist::Zilla::Role::PluginBundle::Config::Slicer
+);
 
 
 
@@ -30,9 +31,8 @@ sub get_value {
     my %defaults = (
         'homepage'            => 'https://metacpan.org/release/%{dist}',
         'repository.github'   => 'user:bioperl',
-        'bugtracker.web'      => 'https://github.com/bioperl/%{dist}',
+        'bugtracker.github'   => 'user:bioperl',
         'bugtracker.mailto'   => 'bioperl-l@bioperl.org',
-        'authority'           => 'cpan:BIOPERLML',
         'trailing_whitespace' => 1,
         'allow_dirty'         => ['Changes', 'dist.ini'],
     );
@@ -51,11 +51,10 @@ has repository_github => (
     default => sub { shift->get_value('repository.github') }
 );
 
-has bugtracker_web => (
+has bugtracker_github => (
     is      => 'lazy',
-    isa     => Uri,
-    coerce  => 1,
-    default => sub { shift->get_value('bugtracker.web') }
+    isa     => Str,
+    default => sub { shift->get_value('bugtracker.github') }
 );
 
 has bugtracker_mailto => (
@@ -64,12 +63,6 @@ has bugtracker_mailto => (
     default => sub { shift->get_value('bugtracker.mailto') }
 );
 
-has authority => (
-    is      => 'lazy',
-    isa     => Str,
-    default => sub { shift->get_value('authority') }
-);
-
 has trailing_whitespace => (
     is      => 'lazy',
     isa     => Bool,
@@ -99,12 +92,10 @@ sub configure {
         PkgVersion
         PodSyntaxTests
         Test::NoTabs
-        NextRelease
         Test::Compile
         PodCoverageTests
         MojibakeTests
         AutoPrereqs
-        RunExtraTests
     ));
 
     my @allow_dirty;
@@ -116,22 +107,24 @@ sub configure {
         [AutoMetaResources => [
             'repository.github' => $self->repository_github,
             'homepage'          => $self->homepage,
+            'bugtracker.github' => $self->bugtracker_github,
         ]],
-        ## AutoMetaResources does not let us configure the bugtracker
         [MetaResources => [
-            'bugtracker.web'    => $self->bugtracker_web,
             'bugtracker.mailto' => $self->bugtracker_mailto,
         ]],
-        [Authority => {
-            authority   => $self->authority,
-            do_metadata => 1,
-        }],
-        [EOLTests => {
+        ['Test::EOL' => {
             trailing_whitespace => $self->trailing_whitespace,
         }],
         [PodWeaver => {
             config_plugin => '@BioPerl',
         }],
+    );
+
+    $self->add_plugins(qw(
+        NextRelease
+    ));
+
+    $self->add_plugins(
         ['Git::Check' => [
             @allow_dirty,
         ]],
@@ -143,7 +136,6 @@ sub configure {
             tag_message => '%N-v%v',
         ]],
     );
-
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -161,7 +153,7 @@ Dist::Zilla::PluginBundle::BioPerl - Build your distributions like Bioperl does
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -189,22 +181,17 @@ equivalent to:
   [PodCoverageTests]    ; create release test for Pod coverage
   [MojibakeTests]       ; create release test for correct encoding
   [AutoPrereqs]         ; automatically find the dependencies
-  [RunExtraTests]       ; run tests /xt directory, normally only needed for release
 
   [AutoMetaResources]   ; automatically fill resources fields on metadata
   repository.github     = user:bioperl
+  bugtracker.github     = user:bioperl
   homepage              = https://metacpan.org/release/${dist}
 
   [MetaResources]       ; fill resources fields on metadata
-  bugtracker.web        = https://github.com/bioperl/${dist}
   bugtracker.mailto     = bioperl-l@bioperl.org
 
-  [Authority]           ; put the $AUTHORITY line in the modules and metadata
-  authority             = cpan:BIOPERLML
-  do_metadata           = 1
-
-  [EOLTests]            ; create release tests for correct line endings
-  trailing_whitespace   = 1
+  [Test::EOL]           ; create release tests for correct line endings
+  trailing_whitespace = 1
 
   [PodWeaver]
   config_plugin = @BioPerl
@@ -228,6 +215,63 @@ problematic distributions:
   -remove = MojibakeTests
   -remove = PodSyntaxTests
 
+=head1 Pushing releases
+
+With this PluginBundle, there's a lot of things happening
+automatically. It might not be clear what actually needs to be done
+and what will be done automatically unless you are already familiar
+with all the plugins being used.  Assuming that F<Changes> is up
+to date (you should be updating F<Changes> as the changes are made
+and not when preparing a release.  If you need to add notes to that
+file, then do it do it at the same time you bump the version number in
+F<dist.ini>), the following steps will make a release:
+
+=over 4
+
+=item 1
+
+Make sure the working directory is clean with `git status'.
+
+=item 2
+
+Run `dzil test --all'
+
+=item 3
+
+Edit dist.ini to bump the version number only.
+
+=item 4
+
+Run `dzil release'
+
+=item 5
+
+Run `git push --tags'
+
+=back
+
+These steps will automatically do the following:
+
+=over 4
+
+=item *
+
+Modify F<Changes> with the version number and time of release.
+
+=item *
+
+Make a git commit with the changes to F<Changes> and F<dist.ini> using a standard commit message.
+
+=item *
+
+Add a lightweight git tag for the release.
+
+=item *
+
+Run the tests (including a series of new tests for maintainers only) and push release to CPAN.
+
+=back
+
 =head1 CONFIGURATION
 
 Use the L<Dist::Zilla::PluginBundle::Filter> to filter any undesired plugin
@@ -255,9 +299,9 @@ Same option used by the L<Dist::Zilla::Plugin::AutoMetaResources>
 
 =item *
 
-bugtracker.web
+bugtracker.github
 
-Same option used by the L<Dist::Zilla::Plugin::MetaResources>
+Same option used by the L<Dist::Zilla::Plugin::AutoMetaResources>
 
 =item *
 
@@ -267,12 +311,6 @@ Same option used by the L<Dist::Zilla::Plugin::MetaResources>
 
 =item *
 
-authority
-
-Same option used by the L<Dist::Zilla::Plugin::Authority>
-
-=item *
-
 trailing_whitespace
 
 Same option used by the L<Dist::Zilla::Plugin::EOLTests>
@@ -327,13 +365,13 @@ Florian Ragwitz <rafl@debian.org>
 
 Sheena Scroggins
 
-CarnÃ« Draug <carandraug+dev@gmail.com
+CarnÃ« Draug <carandraug+dev@gmail.com>
 
-Chris Fields <cjfields1@gmail.com
+Chris Fields <cjfields1@gmail.com>
 
 =head1 COPYRIGHT
 
-This software is copyright (c) 2010 by Florian Ragwitz, 2011 by Sheena Scroggins, and 2013 by CarnÃ« Draug.
+This software is copyright (c) 2010 by Florian Ragwitz, 2011 by Sheena Scroggins, and 2013-2017 by CarnÃ« Draug.
 
 This software is available under the same terms as the perl 5 programming language system itself.
 
