@@ -1,13 +1,10 @@
 package Pod::Weaver::PluginBundle::BioPerl;
-BEGIN {
-  $Pod::Weaver::PluginBundle::BioPerl::AUTHORITY = 'cpan:BIOPERLML';
-}
-$Pod::Weaver::PluginBundle::BioPerl::VERSION = '0.23';
+$Pod::Weaver::PluginBundle::BioPerl::VERSION = '0.24';
 use utf8;
 
 # ABSTRACT: Configure your POD like Bioperl does
-# AUTHOR:   Carnë Draug <carandraug+dev@gmail.com
-# OWNER:    2013 Carnë Draug
+# AUTHOR:   Carnë Draug <carandraug+dev@gmail.com>
+# OWNER:    2013-2017 Carnë Draug
 # LICENSE:  Perl_5
 
 use strict;
@@ -47,7 +44,7 @@ sub mvp_bundle_config {
     ['@BioPerl/Legal',     _exp('Legal::Complicated'), {}                                    ],
     ['@BioPerl/Contributors', _exp('Contributors'), {}                                       ],
 
-    ['Encoding',           _exp('-Encoding'),       { encoding => 'utf-8' }  ],
+    ['SingleEncoding',     _exp('-SingleEncoding'), { encoding => 'UTF-8' }  ],
 
     ['@BioPerl/List',      _exp('-Transformer'),    { transformer => 'List'} ],
 
@@ -100,7 +97,7 @@ Pod::Weaver::PluginBundle::BioPerl - Configure your POD like Bioperl does
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -157,8 +154,8 @@ equivalent to:
   [Legal::Complicated]
   [Contributors]
 
-  [-Encoding]
-  encoding = utf-8
+  [-SingleEncoding]
+  encoding = UTF-8
 
   [-Transformer]
   transformer = List
@@ -200,11 +197,11 @@ web:
 
 =head1 AUTHOR
 
-CarnÃ« Draug <carandraug+dev@gmail.com
+CarnÃ« Draug <carandraug+dev@gmail.com>
 
 =head1 COPYRIGHT
 
-This software is copyright (c) 2013 by CarnÃ« Draug.
+This software is copyright (c) 2013-2017 by CarnÃ« Draug.
 
 This software is available under the same terms as the perl 5 programming language system itself.
 
